@@ -1,9 +1,11 @@
 from Products.CMFCore.utils import getToolByName
-from Products.CMFEditions.setuphandlers import DEFAULT_POLICIES
+try:
+    from Products.CMFEditions.setuphandlers import DEFAULT_POLICIES
+except ImportError:
+    DEFAULT_POLICIES = ('at_edit_autoversion', 'version_on_revert')
 
 # put your custom types in this list
 TYPES_TO_VERSION = ('Organization',)
-print "Organization: in file setuphandler"
 
 def setVersionedTypes(portal):
     portal_repository = getToolByName(portal, 'portal_repository')
@@ -24,7 +26,7 @@ def importVarious(context):
     setVersionedTypes(portal)
     
     #Code to debug which contents types are in the version system
-    print "Organization: setuphandler: importVarious"
+    #print "Organization: setuphandler: importVarious"
     #portal_repository = portal.portal_repository
     #map = portal_repository.getPolicyMap()
     #for i in map.items(): print i
\ No newline at end of file
